@@ -35,7 +35,6 @@
 
 #include "gtksourcelanguage.h"
 #include "gtksourcelanguage-private.h"
-#include "gtksource-marshal.h"
 #include "gtksourceundomanager.h"
 #include "gtksourceundomanagerdefault.h"
 #include "gtksourcestyle.h"
@@ -216,7 +215,6 @@ struct _GtkSourceBufferPrivate
 
 	GtkTextTag *invalid_char_tag;
 
-	guint has_draw_spaces_tag : 1;
 	guint highlight_syntax : 1;
 	guint highlight_brackets : 1;
 	guint implicit_trailing_newline : 1;
@@ -270,53 +268,10 @@ static void	 gtk_source_buffer_real_highlight_updated
 							 GtkTextIter             *start,
 							 GtkTextIter             *end);
 
-static void
-gtk_source_buffer_check_tag_for_spaces (GtkSourceBuffer *buffer,
-                                        GtkSourceTag    *tag)
-{
-	if (!buffer->priv->has_draw_spaces_tag)
-	{
-		gboolean draw_spaces_set;
-
-		g_object_get (tag,
-		              "draw-spaces-set", &draw_spaces_set,
-		              NULL);
-
-		if (draw_spaces_set)
-		{
-			buffer->priv->has_draw_spaces_tag = TRUE;
-		}
-	}
-}
-
-static void
-gtk_source_buffer_tag_changed_cb (GtkTextTagTable *table,
-                                  GtkTextTag      *tag,
-                                  gboolean         size_changed,
-                                  GtkSourceBuffer *buffer)
-{
-	if (GTK_SOURCE_IS_TAG (tag))
-	{
-		gtk_source_buffer_check_tag_for_spaces (buffer, GTK_SOURCE_TAG (tag));
-	}
-}
-
-static void
-gtk_source_buffer_tag_added_cb (GtkTextTagTable *table,
-                                GtkTextTag      *tag,
-                                GtkSourceBuffer *buffer)
-{
-	if (GTK_SOURCE_IS_TAG (tag))
-	{
-		gtk_source_buffer_check_tag_for_spaces (buffer, GTK_SOURCE_TAG (tag));
-	}
-}
-
 static void
 gtk_source_buffer_constructed (GObject *object)
 {
 	GtkSourceBuffer *buffer = GTK_SOURCE_BUFFER (object);
-	GtkTextTagTable *table;
 
 	if (buffer->priv->undo_manager == NULL)
 	{
@@ -325,16 +280,6 @@ gtk_source_buffer_constructed (GObject *object)
 	}
 
 	G_OBJECT_CLASS (gtk_source_buffer_parent_class)->constructed (object);
-
-	table = gtk_text_buffer_get_tag_table (GTK_TEXT_BUFFER (buffer));
-	g_signal_connect_object (table,
-	                         "tag-changed",
-	                         G_CALLBACK (gtk_source_buffer_tag_changed_cb),
-	                         buffer, 0);
-	g_signal_connect_object (table,
-	                         "tag-added",
-	                         G_CALLBACK (gtk_source_buffer_tag_added_cb),
-	                         buffer, 0);
 }
 
 static void
@@ -485,15 +430,11 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	                                G_OBJECT_CLASS_TYPE (object_class),
 	                                G_SIGNAL_RUN_LAST,
 	                                G_CALLBACK (gtk_source_buffer_real_highlight_updated),
-					NULL, NULL,
-					_gtk_source_marshal_VOID__BOXED_BOXED,
+					NULL, NULL, NULL,
 	                                G_TYPE_NONE,
 	                                2,
 	                                GTK_TYPE_TEXT_ITER | G_SIGNAL_TYPE_STATIC_SCOPE,
 	                                GTK_TYPE_TEXT_ITER | G_SIGNAL_TYPE_STATIC_SCOPE);
-	g_signal_set_va_marshaller (buffer_signals[HIGHLIGHT_UPDATED],
-	                            G_TYPE_FROM_CLASS (klass),
-	                            _gtk_source_marshal_VOID__BOXED_BOXEDv);
 
 	/**
 	 * GtkSourceBuffer::source-mark-updated:
@@ -508,13 +449,9 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 			   G_OBJECT_CLASS_TYPE (object_class),
 			   G_SIGNAL_RUN_LAST,
 			   0,
-			   NULL, NULL,
-			   g_cclosure_marshal_VOID__OBJECT,
+			   NULL, NULL, NULL,
 			   G_TYPE_NONE,
 			   1, GTK_TYPE_TEXT_MARK);
-	g_signal_set_va_marshaller (buffer_signals[SOURCE_MARK_UPDATED],
-	                            G_TYPE_FROM_CLASS (klass),
-	                            g_cclosure_marshal_VOID__OBJECTv);
 
 	/**
 	 * GtkSourceBuffer::undo:
@@ -528,12 +465,8 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 			  G_OBJECT_CLASS_TYPE (object_class),
 			  G_SIGNAL_RUN_LAST,
 			  G_STRUCT_OFFSET (GtkSourceBufferClass, undo),
-			  NULL, NULL,
-			  g_cclosure_marshal_VOID__VOID,
+			  NULL, NULL, NULL,
 			  G_TYPE_NONE, 0);
-	g_signal_set_va_marshaller (buffer_signals[UNDO],
-	                            G_TYPE_FROM_CLASS (klass),
-	                            g_cclosure_marshal_VOID__VOIDv);
 
 	/**
 	 * GtkSourceBuffer::redo:
@@ -546,17 +479,13 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 			  G_OBJECT_CLASS_TYPE (object_class),
 			  G_SIGNAL_RUN_LAST,
 			  G_STRUCT_OFFSET (GtkSourceBufferClass, redo),
-			  NULL, NULL,
-			  g_cclosure_marshal_VOID__VOID,
+			  NULL, NULL, NULL,
 			  G_TYPE_NONE, 0);
-	g_signal_set_va_marshaller (buffer_signals[REDO],
-	                            G_TYPE_FROM_CLASS (klass),
-	                            g_cclosure_marshal_VOID__VOIDv);
 
 	/**
 	 * GtkSourceBuffer::bracket-matched:
 	 * @buffer: a #GtkSourceBuffer.
-	 * @iter: (nullable): if found, the location of the matching bracket.
+	 * @iter: if found, the location of the matching bracket.
 	 * @state: state of bracket matching.
 	 *
 	 * @iter is set to a valid iterator pointing to the matching bracket
@@ -575,14 +504,10 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 			  G_OBJECT_CLASS_TYPE (object_class),
 			  G_SIGNAL_RUN_LAST,
 			  G_STRUCT_OFFSET (GtkSourceBufferClass, bracket_matched),
-			  NULL, NULL,
-			  _gtk_source_marshal_VOID__BOXED_ENUM,
+			  NULL, NULL, NULL,
 			  G_TYPE_NONE, 2,
 			  GTK_TYPE_TEXT_ITER,
 			  GTK_SOURCE_TYPE_BRACKET_MATCH_TYPE);
-	g_signal_set_va_marshaller (buffer_signals[BRACKET_MATCHED],
-	                            G_TYPE_FROM_CLASS (klass),
-	                            _gtk_source_marshal_VOID__BOXED_ENUMv);
 }
 
 static void
@@ -2126,12 +2051,6 @@ gtk_source_buffer_create_source_mark (GtkSourceBuffer   *buffer,
 				  GTK_TEXT_MARK (mark),
 				  where);
 
-	/* We want to return a borrowed reference and the mark is already
-	 * owned by @buffer due to gtk_text_buffer_add_mark(). Therefore
-	 * it is safe to unref immediately.
-	 */
-	g_object_unref (mark);
-
 	return mark;
 }
 
@@ -2379,19 +2298,6 @@ gtk_source_buffer_remove_source_marks (GtkSourceBuffer   *buffer,
 	g_slist_free (list);
 }
 
-gboolean
-_gtk_source_buffer_has_source_marks (GtkSourceBuffer *buffer)
-{
-	g_return_val_if_fail (GTK_SOURCE_IS_BUFFER (buffer), FALSE);
-
-	if (buffer->priv->all_source_marks != NULL)
-	{
-		return !_gtk_source_marks_sequence_is_empty (buffer->priv->all_source_marks);
-	}
-
-	return FALSE;
-}
-
 static GtkTextTag *
 get_context_class_tag (GtkSourceBuffer *buffer,
 		       const gchar     *context_class)
@@ -3403,11 +3309,3 @@ gtk_source_buffer_create_source_tag (GtkSourceBuffer *buffer,
 
 	return tag;
 }
-
-gboolean
-_gtk_source_buffer_has_spaces_tag (GtkSourceBuffer *buffer)
-{
-	g_return_val_if_fail (GTK_SOURCE_IS_BUFFER (buffer), FALSE);
-
-	return buffer->priv->has_draw_spaces_tag;
-}
