@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- */
-/* gtksourcestyleschememanager.c
+/*
  * This file is part of GtkSourceView
  *
  * Copyright (C) 2003-2007 - Paolo Maggi <paolo@gnome.org>
@@ -23,10 +23,9 @@
 #endif
 
 #include "gtksourcestyleschememanager.h"
-#include "gtksourcestylescheme.h"
-#include "gtksourceview-i18n.h"
-#include "gtksourceview-utils.h"
 #include <string.h>
+#include "gtksourcestylescheme.h"
+#include "gtksourceutils-private.h"
 
 /**
  * SECTION:styleschememanager
@@ -349,9 +348,9 @@ reload_if_needed (GtkSourceStyleSchemeManager *mgr)
 
 	schemes_hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_object_unref);
 
-	files = _gtk_source_view_get_file_list ((gchar **)gtk_source_style_scheme_manager_get_search_path (mgr),
-						SCHEME_FILE_SUFFIX,
-						FALSE);
+	files = _gtk_source_utils_get_file_list ((gchar **)gtk_source_style_scheme_manager_get_search_path (mgr),
+						 SCHEME_FILE_SUFFIX,
+						 FALSE);
 
 	for (l = files; l != NULL; l = l->next)
 	{
@@ -424,7 +423,7 @@ gtk_source_style_scheme_manager_set_search_path (GtkSourceStyleSchemeManager  *m
 	tmp = manager->priv->search_path;
 
 	if (path == NULL)
-		manager->priv->search_path = _gtk_source_view_get_default_dirs (STYLES_DIR, FALSE);
+		manager->priv->search_path = _gtk_source_utils_get_default_dirs (STYLES_DIR);
 	else
 		manager->priv->search_path = g_strdupv (path);
 
@@ -452,7 +451,7 @@ gtk_source_style_scheme_manager_append_search_path (GtkSourceStyleSchemeManager
 	g_return_if_fail (path != NULL);
 
 	if (manager->priv->search_path == NULL)
-		manager->priv->search_path = _gtk_source_view_get_default_dirs (STYLES_DIR, FALSE);
+		manager->priv->search_path = _gtk_source_utils_get_default_dirs (STYLES_DIR);
 
 	g_return_if_fail (manager->priv->search_path != NULL);
 
@@ -488,7 +487,7 @@ gtk_source_style_scheme_manager_prepend_search_path (GtkSourceStyleSchemeManager
 	g_return_if_fail (path != NULL);
 
 	if (manager->priv->search_path == NULL)
-		manager->priv->search_path = _gtk_source_view_get_default_dirs (STYLES_DIR, FALSE);
+		manager->priv->search_path = _gtk_source_utils_get_default_dirs (STYLES_DIR);
 
 	g_return_if_fail (manager->priv->search_path != NULL);
 
@@ -521,7 +520,7 @@ gtk_source_style_scheme_manager_get_search_path (GtkSourceStyleSchemeManager *ma
 	g_return_val_if_fail (GTK_SOURCE_IS_STYLE_SCHEME_MANAGER (manager), NULL);
 
 	if (manager->priv->search_path == NULL)
-		manager->priv->search_path = _gtk_source_view_get_default_dirs (STYLES_DIR, FALSE);
+		manager->priv->search_path = _gtk_source_utils_get_default_dirs (STYLES_DIR);
 
 	return (const gchar * const *)manager->priv->search_path;
 }
